@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Test::CheckBreaks; # git description: v0.012-12-geed72a8
+package Dist::Zilla::Plugin::Test::CheckBreaks; # git description: v0.013-6-gf2586ff
 # ABSTRACT: Generate a test that shows what modules you are breaking
 # KEYWORDS: distribution prerequisites upstream dependencies modules conflicts breaks breakages metadata
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 use Moose;
 with (
@@ -23,6 +23,11 @@ use Data::Section 0.004 { installer => method_installer }, '-setup';
 use Data::Dumper ();
 use namespace::autoclean;
 
+has no_forced_deps => (
+    is => 'ro', isa => 'Bool',
+    default => 0,
+);
+
 sub filename { path('t', 'zzz-check-breaks.t') }
 
 around dump_config => sub
@@ -32,6 +37,7 @@ around dump_config => sub
 
     $config->{+__PACKAGE__} = {
         conflicts_module => $self->conflicts_module,
+        no_forced_deps => ($self->no_forced_deps ? 1 : 0),
         blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
@@ -81,26 +87,29 @@ sub munge_files
 {
     my $self = shift;
 
-    my $breaks_data = $self->zilla->distmeta->{x_breaks};
+    my $breaks_data = $self->_x_breaks_data;
     $self->log_debug('no x_breaks metadata and no conflicts module found to check against: adding no-op test')
         if not keys %$breaks_data and not $self->conflicts_module;
 
     my $filename = $self->filename;
     my $file = first { $_->name eq $filename } @{ $self->zilla->files };
 
-    $file->content(
-        $self->fill_in_string(
-            $file->content,
-            {
-                dist => \($self->zilla),
-                plugin => \$self,
-                module => \($self->conflicts_module),
-                breaks => \$breaks_data,
-                cmc_prereq => \($self->_cmc_prereq),
-            }
-        )
+    my $content = $self->fill_in_string(
+        $file->content,
+        {
+            dist => \($self->zilla),
+            plugin => \$self,
+            module => \($self->conflicts_module),
+            no_forced_deps => \($self->no_forced_deps),
+            breaks => \$breaks_data,
+            cmc_prereq => \($self->_cmc_prereq),
+            test_count => \($self->_test_count),
+        }
     );
 
+    $content =~ s/\n\n\z/\n/;
+    $file->content($content);
+
     return;
 }
 
@@ -108,20 +117,43 @@ sub register_prereqs
 {
     my $self = shift;
 
-    my $distmeta = $self->zilla->distmeta;
-
     $self->zilla->register_prereqs(
         {
             phase => 'test',
             type  => 'requires',
         },
-        'Test::More' => '0.88',
-        exists $distmeta->{x_breaks} && keys %{ $distmeta->{x_breaks} }
-            ? (
-                'CPAN::Meta::Requirements' => '0',
-                'CPAN::Meta::Check' => $self->_cmc_prereq,
-            ) : (),
+        'Test::More' => '0',
     );
+
+    return if not keys %{ $self->_x_breaks_data };
+
+    $self->zilla->register_prereqs(
+        {
+            phase => 'test',
+            type  => $self->no_forced_deps ? 'suggests' : 'requires',
+        },
+        'CPAN::Meta::Requirements' => '0',
+        'CPAN::Meta::Check' => $self->_cmc_prereq,
+    );
+}
+
+has _x_breaks_data => (
+    is => 'ro', isa => 'HashRef[Str]',
+    init_arg => undef,
+    lazy => 1,
+    default => sub {
+        my $self = shift;
+        my $breaks_data = $self->zilla->distmeta->{x_breaks};
+        defined $breaks_data ? $breaks_data : {};
+    },
+);
+
+sub _test_count {
+    my $self = shift;
+
+    my $test_count = 1; # 1 for conflicts module, always
+    ++$test_count if not keys %{ $self->_x_breaks_data };
+    return $test_count;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -173,6 +205,15 @@ __PACKAGE__->meta->make_immutable;
 #pod L<[Conflicts]|Dist::Zilla::Plugin::Conflicts> to be used in your distribution;
 #pod this is only a feature added for backwards compatibility.
 #pod
+#pod =head2 C<no_forced_deps>
+#pod
+#pod Suitable for distributions that do not wish to add a C<test requires>
+#pod prerequisite on L<CPAN::Meta::Requirements> and L<CPAN::Meta::Check> --
+#pod instead, the dependencies will be added as C<test suggests>, and the generated
+#pod test will gracefully skip checks if these modules are not available.
+#pod
+#pod Available since version 0.014.
+#pod
 #pod =for Pod::Coverage filename gather_files munge_files register_prereqs
 #pod
 #pod =head1 BACKGROUND
@@ -215,7 +256,7 @@ Dist::Zilla::Plugin::Test::CheckBreaks - Generate a test that shows what modules
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -262,6 +303,15 @@ There is no error if the module does not exist. This test does not require
 L<[Conflicts]|Dist::Zilla::Plugin::Conflicts> to be used in your distribution;
 this is only a feature added for backwards compatibility.
 
+=head2 C<no_forced_deps>
+
+Suitable for distributions that do not wish to add a C<test requires>
+prerequisite on L<CPAN::Meta::Requirements> and L<CPAN::Meta::Check> --
+instead, the dependencies will be added as C<test suggests>, and the generated
+test will gracefully skip checks if these modules are not available.
+
+Available since version 0.014.
+
 =for Pod::Coverage filename gather_files munge_files register_prereqs
 
 =head1 BACKGROUND
@@ -315,7 +365,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-irc://irc.perl.org/#distzilla.
+L<irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
@@ -343,9 +393,9 @@ ___[ test-check-breaks ]___
 use strict;
 use warnings;
 
-# this test was generated with {{ ref($plugin) . ' ' . $plugin->VERSION }}
+# this test was generated with {{ ref $plugin }} {{ $plugin->VERSION }}
 
-use Test::More 0.88;
+use Test::More tests => {{ $test_count }};
 
 SKIP: {
 {{
@@ -374,28 +424,34 @@ CHECK_CONFLICTS
         $dumper->Indent(1);
         $dumper->Useqq(1);
         my $dist_name = $dist->name;
-        '# this data duplicates x_breaks in META.json' . "\n"
-        . 'my ' . $dumper->Dump . <<'CHECK_BREAKS_1a'
+        ($no_forced_deps ? 'SKIP: {' . "\n" : '')
+        . '# this data duplicates x_breaks in META.json' . "\n"
+        . 'my ' . $dumper->Dump
 
-use CPAN::Meta::Requirements;
+        . "\n" . join("\n", $no_forced_deps
+            ?
+                (map { "skip 'This information-only test requires $_', 0\n    if not eval 'require $_';" }
+                    'CPAN::Meta::Requirements', 'CPAN::Meta::Check')
+            :
+                ('use CPAN::Meta::Requirements;', "use CPAN::Meta::Check $cmc_prereq;"))
+        . "\n\n"
+
+    . <<'CHECK_BREAKS_1b'
 my $reqs = CPAN::Meta::Requirements->new;
 $reqs->add_string_requirement($_, $breaks->{$_}) foreach keys %$breaks;
 
-CHECK_BREAKS_1a
-    . "use CPAN::Meta::Check $cmc_prereq 'check_requirements';\n"
-    . <<'CHECK_BREAKS_1b'
-our $result = check_requirements($reqs, 'conflicts');
+our $result = CPAN::Meta::Check::check_requirements($reqs, 'conflicts');
 
 if (my @breaks = grep { defined $result->{$_} } keys %$result)
 {
 CHECK_BREAKS_1b
     . "    diag 'Breakages found with $dist_name:';\n"
-    . <<'CHECK_BREAKS_2';
+    . <<'CHECK_BREAKS_2'
     diag "$result->{$_}" for sort @breaks;
     diag "\n", 'You should now update these modules!';
 }
 CHECK_BREAKS_2
+        . ($no_forced_deps ? '}' . "\n" : '')
     }
     else { q{pass 'no x_breaks data to check';} . "\n" }
 }}
-done_testing;
